@@ -82,6 +82,7 @@
 #' @seealso \code{\link{plot_hist}}
 #'
 #' @examples
+#' \dontrun{
 #' # First, load the example data
 #' data(bunching_data)
 #'
@@ -135,7 +136,7 @@
 #'                  correct = FALSE, notch = TRUE,p_b = TRUE, p_b_e_xpos = 8900,
 #'                  n_boot = 0)
 #' notch$plot
-
+#'}
 
 #' @export
 
@@ -511,7 +512,7 @@ bunchit <- function(z_vector, binv = "median", zstar, binwidth, bins_l, bins_r,
         zD <- NA
         zU_notch <- NA
         firstpass <- bunching::fit_bunching(firstpass_prep$data_binned, firstpass_prep$model_formula,
-                                            notch, zD_bin)
+                                            binwidth, notch, zD_bin)
 
     } else if (notch == TRUE) {
         # calculate z_dominated for notches
@@ -527,7 +528,7 @@ bunchit <- function(z_vector, binv = "median", zstar, binwidth, bins_l, bins_r,
                                                           poly, bins_excl_l, bins_excl_r, rn, extra_fe,
                                                           correct_above_zu)
             # fit firstpass model
-            firstpass <- bunching::fit_bunching(firstpass_prep$data_binned, firstpass_prep$model_formula, notch, zD_bin)
+            firstpass <- bunching::fit_bunching(firstpass_prep$data_binned, firstpass_prep$model_formula, binwidth, notch, zD_bin)
 
 
 
@@ -537,7 +538,7 @@ bunchit <- function(z_vector, binv = "median", zstar, binwidth, bins_l, bins_r,
             firstpass_prep <- bunching::prep_data_for_fit(binned_data, zstar, binwidth, bins_l, bins_r,
                                                           poly, bins_excl_l, bins_excl_r, rn, extra_fe,
                                                           correct_above_zu)
-            firstpass <- bunching::fit_bunching(firstpass_prep$data_binned, firstpass_prep$model_formula, notch, zD_bin)
+            firstpass <- bunching::fit_bunching(firstpass_prep$data_binned, firstpass_prep$model_formula, binwidth, notch, zD_bin)
 
             # extract bunching mass below and missing mass above zstar
             B_below <- firstpass$B_zl_zstar
@@ -574,7 +575,7 @@ bunchit <- function(z_vector, binv = "median", zstar, binwidth, bins_l, bins_r,
                 # add next order bin_excl_r to formula
                 tmp_firstpass_prep$model_formula <- stats::as.formula(paste(Reduce(paste, deparse(tmp_firstpass_prep$model_formula)), newvar, sep = " + "))
                 # re-fit model using the now expanded zu
-                tmp_firstpass <- bunching::fit_bunching(tmp_firstpass_prep$data_binned, tmp_firstpass_prep$model_formula, notch, zD_bin)
+                tmp_firstpass <- bunching::fit_bunching(tmp_firstpass_prep$data_binned, tmp_firstpass_prep$model_formula, binwidth, notch, zD_bin)
                 # get new B below and M above
                 B_below <- tmp_firstpass$B_zl_zstar
                 M_above <- -tmp_firstpass$B_zstar_zu
@@ -748,7 +749,7 @@ bunchit <- function(z_vector, binv = "median", zstar, binwidth, bins_l, bins_r,
                                  t0 = t0, t1 = t1, notch = notch, p_domregion_color = p_domregion_color,
                                  p_domregion_ltype = p_domregion_ltype)
     # set rounding
-    round_dp <- 3
+    round_dp <- 9
 
     output <- list("plot" = p,
                    "data" = firstpass_prep$data_binned,
